@@ -8,10 +8,11 @@ use tracing::{debug, trace};
 
 use uv_cache::Cache;
 use uv_client::BaseClientBuilder;
-use uv_configuration::{Concurrency, Constraints, DryRun, Preview};
+use uv_configuration::{Concurrency, Constraints, DryRun, TargetTriple};
 use uv_distribution_types::{ExtraBuildRequires, Requirement};
 use uv_fs::CWD;
 use uv_normalize::PackageName;
+use uv_preview::Preview;
 use uv_python::{
     EnvironmentPreference, Interpreter, PythonDownloads, PythonInstallation, PythonPreference,
     PythonRequest,
@@ -33,16 +34,17 @@ use crate::commands::reporters::PythonDownloadReporter;
 use crate::commands::tool::common::remove_entrypoints;
 use crate::commands::{ExitStatus, conjunction, tool::common::finalize_tool_install};
 use crate::printer::Printer;
-use crate::settings::{NetworkSettings, ResolverInstallerSettings};
+use crate::settings::ResolverInstallerSettings;
 
 /// Upgrade a tool.
 pub(crate) async fn upgrade(
     names: Vec<String>,
     python: Option<String>,
+    python_platform: Option<TargetTriple>,
     install_mirrors: PythonInstallMirrors,
     args: ResolverInstallerOptions,
     filesystem: ResolverInstallerOptions,
-    network_settings: NetworkSettings,
+    client_builder: BaseClientBuilder<'_>,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
     installer_metadata: bool,
@@ -81,11 +83,6 @@ pub(crate) async fn upgrade(
     }
 
     let reporter = PythonDownloadReporter::single(printer);
-    let client_builder = BaseClientBuilder::new()
-        .retries_from_env()?
-        .connectivity(network_settings.connectivity)
-        .native_tls(network_settings.native_tls)
-        .allow_insecure_host(network_settings.allow_insecure_host.clone());
 
     let python_request = python.as_deref().map(PythonRequest::parse);
 
@@ -124,10 +121,11 @@ pub(crate) async fn upgrade(
             name,
             constraints,
             interpreter.as_ref(),
+            python_platform.as_ref(),
             printer,
             &installed_tools,
             &args,
-            &network_settings,
+            &client_builder,
             cache,
             &filesystem,
             installer_metadata,
@@ -209,10 +207,11 @@ async fn upgrade_tool(
     name: &PackageName,
     constraints: &[Requirement],
     interpreter: Option<&Interpreter>,
+    python_platform: Option<&TargetTriple>,
     printer: Printer,
     installed_tools: &InstalledTools,
     args: &ResolverInstallerOptions,
-    network_settings: &NetworkSettings,
+    client_builder: &BaseClientBuilder<'_>,
     cache: &Cache,
     filesystem: &ResolverInstallerOptions,
     installer_metadata: bool,
@@ -295,9 +294,10 @@ async fn upgrade_tool(
         let resolution = resolve_environment(
             spec.into(),
             interpreter,
+            python_platform,
             build_constraints.clone(),
             &settings.resolver,
-            network_settings,
+            client_builder,
             &state,
             Box::new(SummaryResolveLogger),
             concurrency,
@@ -315,7 +315,7 @@ async fn upgrade_tool(
             Modifications::Exact,
             build_constraints,
             (&settings).into(),
-            network_settings,
+            client_builder,
             &state,
             Box::new(DefaultInstallLogger),
             installer_metadata,
@@ -338,10 +338,11 @@ async fn upgrade_tool(
             environment,
             spec,
             Modifications::Exact,
+            python_platform,
             build_constraints,
             ExtraBuildRequires::default(),
             &settings,
-            network_settings,
+            client_builder,
             &state,
             Box::new(SummaryResolveLogger),
             Box::new(UpgradeInstallLogger::new(name.clone())),
